@@ -29,7 +29,6 @@ import           Lens.Micro.Platform (non)
 
 import qualified Network.Mattermost.Types as MM
 
-import           Matterhorn.Constants ( userSigil )
 import           Matterhorn.Draw.Util
 import           Matterhorn.State.Channels
 import           Matterhorn.Themes
@@ -65,7 +64,7 @@ renderChannelListHeader st =
                      txt $ "Team: " <> teamNameStr
         selfHeader = hCenter $
                      colorUsername myUsername_ myUsername_
-                         (T.singleton statusSigil <> " " <> userSigil <> myUsername_)
+                         (T.singleton statusSigil <> " " <> addUserSigil myUsername_)
         teamNameStr = T.strip $ sanitizeUserText $ MM.teamDisplayName $ st^.csCurrentTeam.tsTeam
         statusSigil = maybe ' ' userSigilFromInfo me
         me = userById (myUserId st) st
@@ -78,7 +77,7 @@ renderChannelList st =
     where
         myUsername_ = myUsername st
         channelName e = ClickableChannelListEntry $ channelListEntryChannelId  e
-        renderEntry s e = clickable (channelName e) $ 
+        renderEntry s e = clickable (channelName e) $
                           renderChannelListEntry myUsername_ $ mkChannelEntryData s e
         tId = st^.csCurrentTeamId
         body = case st^.csCurrentTeam.tsMode of
@@ -100,11 +99,12 @@ renderChannelList st =
 
 renderChannelListGroupHeading :: ChannelListGroup -> Widget Name
 renderChannelListGroupHeading g =
-    let (unread, label) = case g of
-            ChannelGroupPublicChannels u -> (u, "Public Channels")
-            ChannelGroupPrivateChannels u -> (u, "Private Channels")
-            ChannelGroupFavoriteChannels u -> (u, "Favorite Channels")
-            ChannelGroupDirectMessages u -> (u, "Direct Messages")
+    let label = case channelListGroupLabel g of
+            ChannelGroupPublicChannels   -> "Public Channels"
+            ChannelGroupPrivateChannels  -> "Private Channels"
+            ChannelGroupFavoriteChannels -> "Favorite Channels"
+            ChannelGroupDirectMessages   -> "Direct Messages"
+        unread = channelListGroupUnread g
         addUnread = if unread > 0
                     then (<+> (withDefAttr unreadGroupMarkerAttr $ txt "*"))
                     else id
@@ -143,7 +143,7 @@ mkChannelEntryData st e =
         recent = isRecentChannel st cId
         ret = isReturnChannel st cId
         current = isCurrentChannel st cId
-        muted = isMuted chan
+        muted = channelListEntryMuted e
         (name, normalSigil, addSpace, status) = case channelListEntryType e of
             CLChannel ->
                 (chan^.ccInfo.cdDisplayName, Nothing, False, Nothing)
