@@ -46,14 +46,14 @@ renderUrlList st =
           let time = link^.linkTime
           in attr sel $ vLimit 2 $
             (vLimit 1 $
-             hBox [ let u = maybe "<server>" id (link^.linkUser.to (nameForUserRef st))
+             hBox [ let u = maybe "<server>" id (link^.linkUser.to (printableNameForUserRef st))
                     in colorUsername me u u
                   , case link^.linkLabel of
                       Nothing -> emptyWidget
                       Just label ->
                           case Seq.null (unInlines label) of
                               True -> emptyWidget
-                              False -> txt ": " <+> renderRichText me hSet Nothing False Nothing
+                              False -> txt ": " <+> renderRichText me hSet Nothing False Nothing Nothing
                                                     (Blocks $ Seq.singleton $ Para label)
                   , fill ' '
                   , renderDate st $ withServerTime time
