@@ -26,8 +26,6 @@ import           Matterhorn.State.Channels
 import           Matterhorn.State.Common
 import           Matterhorn.State.Help
 import           Matterhorn.State.Messages
-import           Matterhorn.State.Teams ( setTeam )
-import           Matterhorn.State.ListOverlay ( listOverlayActivate )
 import           Matterhorn.Types
 
 import           Matterhorn.Events.ChannelSelect
@@ -45,12 +43,11 @@ import           Matterhorn.Events.UrlSelect
 import           Matterhorn.Events.UserListOverlay
 import           Matterhorn.Events.ChannelListOverlay
 import           Matterhorn.Events.ReactionEmojiListOverlay
-import           Matterhorn.State.Reactions ( toggleReaction )
 import           Matterhorn.Events.TabbedWindow
 import           Matterhorn.Events.ManageAttachments
+import           Matterhorn.Events.Mouse
 import           Matterhorn.Events.EditNotifyPrefs
 import           Matterhorn.Events.Websocket
-import           Matterhorn.State.Links ( openLinkTarget )
 
 onEvent :: ChatState -> BrickEvent Name MHEvent -> EventM Name (Next ChatState)
 onEvent st ev = runMHEvent st $ do
@@ -66,10 +63,7 @@ onBrickEvent (VtyEvent (Vty.EvKey (Vty.KChar 'l') [Vty.MCtrl])) = do
     liftIO $ Vty.refresh vty
 onBrickEvent (VtyEvent e) =
     onVtyEvent e
-onBrickEvent (MouseUp {}) = do
-    mhLog LogGeneral "MOUSE UP EVENT"
-    csLastMouseDownEvent .= Nothing
-onBrickEvent e@(MouseDown n button modifier clickLoc) = do
+onBrickEvent e@(MouseDown n button modifier _) = do
     mhLog LogGeneral $ T.pack $ "MOUSE EVENT: " <> show (n, button, modifier)
     lastClick <- use csLastMouseDownEvent
     let shouldHandle = case lastClick of
@@ -79,7 +73,11 @@ onBrickEvent e@(MouseDown n button modifier clickLoc) = do
     when shouldHandle $ do
         mhLog LogGeneral "Handling mouse event"
         csLastMouseDownEvent .= Just e
-        onMouseDown n button modifier clickLoc
+        mode <- use (csCurrentTeam.tsMode)
+        mouseHandlerByMode mode e
+onBrickEvent (MouseUp {}) = do
+    csLastMouseDownEvent .= Nothing
+    mhContinueWithoutRedraw
 
 onAppEvent :: MHEvent -> MH ()
 onAppEvent RefreshWebsocketEvent =
@@ -127,7 +125,7 @@ onAppEvent (IEvent e) = do
 
 handleIEvent :: InternalEvent -> MH ()
 handleIEvent (DisplayError e) =
-    postErrorMessage' $ formatError e
+    postErrorMessage' $ formatMHError e
 handleIEvent (LoggingStarted path) =
     postInfoMessage $ "Logging to " <> T.pack path
 handleIEvent (LogDestination dest) =
@@ -147,92 +145,33 @@ handleIEvent (LogSnapshotFailed path err) =
     postErrorMessage' $ "Could not write log snapshot to " <> T.pack path <>
                         ", error: " <> T.pack err
 
--- Handle mouse click events.
---
--- Note that the handler for each case may need to check the application
--- mode before handling the click. This is because some mouse events
--- only make sense when the UI is displaying certain contents. While
--- it's true that we probably wouldn't even get the click events in the
--- first place (because the UI element would only cause a click event
--- to be reported if it was actually rendered), there are cases when we
--- can get clicks on UI elements that *are* clickable even though those
--- clicks don't make sense for the application mode. A concrete example
--- of this is when we display the current channel's contents in one
--- layer, in monochrome, and then display a modal dialog box on top of
--- that. We probably *should* ignore clicks on the lower layer because
--- that's not the mode the application is in, but getting that right
--- could be hard because we'd have to figure out all possible modes
--- where those lower-layer clicks would be nonsensical. We don't bother
--- doing that in the harder cases; instead we just handle the clicks
--- and do what we would ordinarily do, assuming that there's no real
--- harm done. The worst that could happen is that a user could click
--- accidentally on a grayed-out URL (in a message, say) next to a modal
--- dialog box and then see the URL get opened. That would be weird, but
--- it isn't the end of the world.
-onMouseDown :: Name -> Vty.Button -> [Vty.Modifier] -> Location -> MH()
-onMouseDown (ClickableChannelListEntry channelId) Vty.BLeft [] _ = do
-    whenMode Main $ do
-        resetReturnChannel
-        setFocus channelId
-        setMode Main
-onMouseDown (ClickableTeamListEntry teamId) Vty.BLeft [] _ =
-    -- We deliberately handle this event in all modes; this allows us to
-    -- switch the UI to another team regardless of what state it is in,
-    -- which is by design since all teams have their own UI states.
-    setTeam teamId
-onMouseDown (ClickableURLInMessage _ _ t) Vty.BLeft [] _ =
-    void $ openLinkTarget t
-onMouseDown (ClickableURL _ _ t) Vty.BLeft [] _ =
-    void $ openLinkTarget t
-onMouseDown (ClickableUsernameInMessage _ _ username) Vty.BLeft [] _ =
-    changeChannelByName $ userSigil <> username
-onMouseDown (ClickableUsername _ _ username) Vty.BLeft [] _ =
-    changeChannelByName $ userSigil <> username
-onMouseDown (ClickableURLListEntry _ t) Vty.BLeft [] _ =
-    -- Only handle URL list entry clicks when viewing the URL list
-    whenMode UrlSelect $ do
-        void $ openLinkTarget t
-onMouseDown (ChannelSelectEntry match) Vty.BLeft [] _ =
-    whenMode ChannelSelect $ do
-        setMode Main
-        setFocus $ channelListEntryChannelId $ matchEntry match
-onMouseDown (ClickableReactionInMessage pId t uIds) Vty.BLeft [] _ =
-    void $ toggleReaction pId t uIds
-onMouseDown (ClickableReaction pId t uIds) Vty.BLeft [] _ =
-    void $ toggleReaction pId t uIds
-onMouseDown (ReactionEmojiListOverlayEntry val) Vty.BLeft [] _ =
-    whenMode ReactionEmojiListOverlay $ do
-        listOverlayActivate (csCurrentTeam.tsReactionEmojiListOverlay) val
-onMouseDown _ _ _ _ =
-    return ()
-
-formatError :: MHError -> T.Text
-formatError (GenericError msg) =
+formatMHError :: MHError -> T.Text
+formatMHError (GenericError msg) =
     msg
-formatError (NoSuchChannel chan) =
+formatMHError (NoSuchChannel chan) =
     T.pack $ "No such channel: " <> show chan
-formatError (NoSuchUser user) =
+formatMHError (NoSuchUser user) =
     T.pack $ "No such user: " <> show user
-formatError (AmbiguousName name) =
+formatMHError (AmbiguousName name) =
     (T.pack $ "The input " <> show name <> " matches both channels ") <>
     "and users. Try using '" <> userSigil <> "' or '" <>
     normalChannelSigil <> "' to disambiguate."
-formatError (ServerError e) =
+formatMHError (ServerError e) =
     mattermostErrorMessage e
-formatError (ClipboardError msg) =
+formatMHError (ClipboardError msg) =
     msg
-formatError (ConfigOptionMissing opt) =
+formatMHError (ConfigOptionMissing opt) =
     T.pack $ "Config option " <> show opt <> " missing"
-formatError (ProgramExecutionFailed progName logPath) =
+formatMHError (ProgramExecutionFailed progName logPath) =
     T.pack $ "An error occurred when running " <> show progName <>
              "; see " <> show logPath <> " for details."
-formatError (NoSuchScript name) =
+formatMHError (NoSuchScript name) =
     "No script named " <> name <> " was found"
-formatError (NoSuchHelpTopic topic) =
+formatMHError (NoSuchHelpTopic topic) =
     let knownTopics = ("  - " <>) <$> helpTopicName <$> helpTopics
     in "Unknown help topic: `" <> topic <> "`. " <>
        (T.unlines $ "Available topics are:" : knownTopics)
-formatError (AttachmentException e) =
+formatMHError (AttachmentException e) =
     case fromException e of
       Just (ioe :: IO.IOError) ->
           if IO.isDoesNotExistError ioe
@@ -243,9 +182,9 @@ formatError (AttachmentException e) =
       Nothing -> "Unknown error attaching file!\n" <>
           "Please report this error at https://github.com/matterhorn-chat/matterhorn/issues"
           -- this case shouldn't be reached
-formatError (BadAttachmentPath msg) =
+formatMHError (BadAttachmentPath msg) =
     msg
-formatError (AsyncErrEvent e) =
+formatMHError (AsyncErrEvent e) =
     "An unexpected error has occurred! The exception encountered was:\n  " <>
     T.pack (show e) <>
     "\nPlease report this error at https://github.com/matterhorn-chat/matterhorn/issues"
