@@ -15,6 +15,7 @@ module Matterhorn.State.Messages
   , fetchVisibleIfNeeded
   , disconnectChannels
   , toggleMessageTimestamps
+  , toggleVerbatimBlockTruncation
   , jumpToPost
   )
 where
@@ -83,6 +84,20 @@ toggleMessageTimestamps = do
                      }
     csResources.crConfiguration %= toggle
 
+defaultVerbatimTruncateHeight :: Int
+defaultVerbatimTruncateHeight = 25
+
+toggleVerbatimBlockTruncation :: MH ()
+toggleVerbatimBlockTruncation = do
+    mh invalidateCache
+    st <- use id
+    -- Restore the configured setting, or a default if the configuration
+    -- does not specify a setting.
+    let toggle Nothing = (st^.csResources.crConfiguration.configTruncateVerbatimBlocksL) <|>
+                         Just defaultVerbatimTruncateHeight
+        toggle (Just _) = Nothing
+    csVerbatimTruncateSetting %= toggle
+
 clearPendingFlags :: ChannelId -> MH ()
 clearPendingFlags c = csChannel(c).ccContents.cdFetchPending .= False
 
@@ -165,6 +180,7 @@ editMessage new = do
 
         csChannel (new^.postChannelIdL) . ccContents . cdMessages . traversed . filtered isEditedMessage .= msg
         mh $ invalidateCacheEntry (ChannelMessages $ new^.postChannelIdL)
+        mh $ invalidateCacheEntry $ RenderedMessage $ MessagePostId $ postId new
 
         fetchMentionedUsers mentionedUsers
 
@@ -184,6 +200,7 @@ deleteMessage new = do
     chan.ccContents.cdMessages.traversed.filtered isDeletedMessage %= (& mDeleted .~ True)
     chan %= adjustUpdated new
     mh $ invalidateCacheEntry (ChannelMessages $ new^.postChannelIdL)
+    mh $ invalidateCacheEntry $ RenderedMessage $ MessagePostId $ postId new
 
 addNewPostedMessage :: PostToAdd -> MH ()
 addNewPostedMessage p =
@@ -551,6 +568,7 @@ addMessageToState doFetchMentionedUsers fetchAuthor newPostData = do
 
                     csPostMap.at(postId new) .= Just msg'
                     mh $ invalidateCacheEntry (ChannelMessages cId)
+                    mh $ invalidateCacheEntry $ RenderedMessage $ MessagePostId $ postId new
                     csChannels %= modifyChannelById cId
                       ((ccContents.cdMessages %~ addMessage msg') .
                        (if not ignoredJoinLeaveMessage then adjustUpdated new else id) .
@@ -949,7 +967,9 @@ asyncFetchAttachments p = do
                     m
         return $ Just $ do
             csChannel(cId).ccContents.cdMessages.traversed %= addAttachment
-            mh $ invalidateCacheEntry $ ChannelMessages cId
+            mh $ do
+                invalidateCacheEntry $ ChannelMessages cId
+                invalidateCacheEntry $ RenderedMessage $ MessagePostId pId
 
 -- | Given a post ID, switch to that post's channel and select the post
 -- in message selection mode.
