@@ -10,6 +10,7 @@ module Matterhorn.Themes
   -- * Attribute names
   , currentUserAttr
   , timeAttr
+  , verbatimTruncateMessageAttr
   , channelHeaderAttr
   , channelListHeaderAttr
   , currentChannelNameAttr
@@ -21,6 +22,8 @@ module Matterhorn.Themes
   , codeAttr
   , emailAttr
   , emojiAttr
+  , reactionAttr
+  , myReactionAttr
   , channelNameAttr
   , clientMessageAttr
   , clientHeaderAttr
@@ -145,6 +148,9 @@ currentUserAttr = "currentUser"
 channelHeaderAttr :: AttrName
 channelHeaderAttr = "channelHeader"
 
+verbatimTruncateMessageAttr :: AttrName
+verbatimTruncateMessageAttr = "verbatimTruncateMessage"
+
 channelListHeaderAttr :: AttrName
 channelListHeaderAttr = "channelListSectionHeader"
 
@@ -190,6 +196,12 @@ emailAttr = "email"
 emojiAttr :: AttrName
 emojiAttr = "emoji"
 
+reactionAttr :: AttrName
+reactionAttr = "reaction"
+
+myReactionAttr :: AttrName
+myReactionAttr = reactionAttr <> "mine"
+
 clientMessageAttr :: AttrName
 clientMessageAttr = "clientMessage"
 
@@ -259,7 +271,7 @@ lightColorTheme = InternalTheme name theme desc
         theme = newTheme def $ lightAttrs usernameColors16
         name = "builtin:light"
         def = black `on` white
-        desc = "A color theme for terminal windows with light background colors"
+        desc = "A 16-color theme for terminal windows with light background colors"
 
 lightColor256Theme :: InternalTheme
 lightColor256Theme = InternalTheme name theme desc
@@ -277,6 +289,7 @@ lightAttrs usernameColors =
        , (buttonFocusedAttr,                black `on` yellow)
        , (currentUserAttr,                  defAttr `withStyle` bold)
        , (channelHeaderAttr,                fg black)
+       , (verbatimTruncateMessageAttr,      fg blue)
        , (channelListHeaderAttr,            fg cyan)
        , (currentChannelNameAttr,           black `on` yellow `withStyle` bold)
        , (unreadChannelAttr,                black `on` cyan   `withStyle` bold)
@@ -286,6 +299,8 @@ lightAttrs usernameColors =
        , (emailAttr,                        fg yellow)
        , (codeAttr,                         fg magenta)
        , (emojiAttr,                        fg yellow)
+       , (reactionAttr,                     fg yellow)
+       , (myReactionAttr,                   fg yellow `withStyle` underline)
        , (channelNameAttr,                  fg blue)
        , (clientMessageAttr,                fg black)
        , (clientEmphAttr,                   fg black `withStyle` bold)
@@ -339,6 +354,7 @@ darkAttrs usernameColors =
      , (buttonFocusedAttr,                black `on` yellow)
      , (currentUserAttr,                  defAttr `withStyle` bold)
      , (channelHeaderAttr,                fg white)
+     , (verbatimTruncateMessageAttr,      fg cyan)
      , (channelListHeaderAttr,            fg cyan)
      , (currentChannelNameAttr,           black `on` yellow `withStyle` bold)
      , (unreadChannelAttr,                black `on` cyan   `withStyle` bold)
@@ -348,6 +364,8 @@ darkAttrs usernameColors =
      , (emailAttr,                        fg yellow)
      , (codeAttr,                         fg magenta)
      , (emojiAttr,                        fg yellow)
+     , (reactionAttr,                     fg yellow)
+     , (myReactionAttr,                   fg yellow `withStyle` underline)
      , (channelNameAttr,                  fg cyan)
      , (pinnedMessageIndicatorAttr,       fg cyan `withStyle` bold)
      , (clientMessageAttr,                fg white)
@@ -402,7 +420,7 @@ darkColorTheme = InternalTheme name theme desc
         theme = newTheme def $ darkAttrs usernameColors16
         name = "builtin:dark"
         def = defAttr
-        desc = "A color theme for terminal windows with dark background colors"
+        desc = "A 16-color theme for terminal windows with dark background colors"
 
 darkColor256Theme :: InternalTheme
 darkColor256Theme = InternalTheme name theme desc
@@ -581,6 +599,12 @@ themeDocs = ThemeDocumentation $ M.fromList $
     , ( emojiAttr
       , "A text emoji indication in a chat message"
       )
+    , ( reactionAttr
+      , "An emoji reaction on a chat message"
+      )
+    , ( myReactionAttr
+      , "An emoji reaction that the current user has posted on a chat message"
+      )
     , ( channelNameAttr
       , "A channel name in a chat message"
       )
@@ -821,6 +845,9 @@ themeDocs = ThemeDocumentation $ M.fromList $
     , ( currentTeamAttr
       , "The currently-selected team"
       )
+    , ( verbatimTruncateMessageAttr
+      , "Attribute for a message indicating that a verbatim or code block has been only partially displayed"
+      )
     ] <> [ (usernameAttr i, T.pack $ "Username color " <> show i)
          | i <- [0..usernameColorHashBuckets-1]
          ]
