@@ -29,7 +29,7 @@ import           Matterhorn.Themes
 import           Matterhorn.Types
 import           Matterhorn.Types.RichText ( Inline(EUser) )
 import           Matterhorn.Draw.RichText
-import           Matterhorn.Draw.Messages ( renderMessage, MessageData(..), nameForUserRef )
+import           Matterhorn.Draw.Messages ( renderMessage, MessageData(..), printableNameForUserRef )
 
 -- | The template for "View Message" windows triggered by message
 -- selection mode.
@@ -126,7 +126,7 @@ reactionsText st m = viewport (ViewMessageReactionsArea tId) Vertical body
         usernameText uids =
             renderText' Nothing (myUsername st) hs (Just clickableUsernames) $
             T.intercalate ", " $
-            fmap (userSigil <>) $
+            fmap addUserSigil $
             catMaybes (lookupUsername <$> F.toList uids)
 
         lookupUsername uid = usernameForUserId uid st
@@ -157,9 +157,9 @@ viewMessageBox st msg =
                 md = MessageData { mdEditThreshold     = Nothing
                                  , mdShowOlderEdits    = False
                                  , mdMessage           = msg
-                                 , mdUserName          = msg^.mUser.to (nameForUserRef st)
+                                 , mdUserName          = msg^.mUser.to (printableNameForUserRef st)
                                  , mdParentMessage     = parent
-                                 , mdParentUserName    = parent >>= (^.mUser.to (nameForUserRef st))
+                                 , mdParentUserName    = parent >>= (^.mUser.to (printableNameForUserRef st))
                                  , mdRenderReplyParent = True
                                  , mdHighlightSet      = hs
                                  , mdIndentBlocks      = True
@@ -167,7 +167,9 @@ viewMessageBox st msg =
                                  , mdShowReactions     = False
                                  , mdMessageWidthLimit = Just vpWidth
                                  , mdMyUsername        = myUsername st
+                                 , mdMyUserId          = myUserId st
                                  , mdWrapNonhighlightedCodeBlocks = False
+                                 , mdTruncateVerbatimBlocks = Nothing
                                  }
             in renderMessage md
 
